@@ -28,11 +28,11 @@
 #include <libgen.h>
 #include "ctree.h"
 #include "transaction.h"
-#include "utils.h"
+#include "common/utils.h"
 #include "ioctl.h"
 #include <uuid/uuid.h>
 #include "btrfs-list.h"
-#include "rbtree-utils.h"
+#include "common/rbtree-utils.h"
 
 #define BTRFS_LIST_NFILTERS_INCREASE	(2 * BTRFS_LIST_FILTER_MAX)
 #define BTRFS_LIST_NCOMPS_INCREASE	(2 * BTRFS_LIST_COMP_MAX)
@@ -515,8 +515,9 @@ static int add_root(struct root_lookup *root_lookup,
 
 	ret = root_tree_insert(root_lookup, ri);
 	if (ret < 0) {
-		error("failed to insert subvolume %llu to tree: %s",
-				(unsigned long long)root_id, strerror(-ret));
+		errno = -ret;
+		error("failed to insert subvolume %llu to tree: %m",
+				(unsigned long long)root_id);
 		exit(1);
 	}
 	return 0;
