@@ -21,14 +21,14 @@
 #include "version.h"
 #include "kernel-lib/rbtree.h"
 #include "kernel-lib/radix-tree.h"
-#include "kernel-lib/crc32c.h"
+#include "crypto/crc32c.h"
 #include "kernel-lib/list.h"
 #include "kernel-lib/sizes.h"
 #include "ctree.h"
 #include "extent_io.h"
 #include "ioctl.h"
 #include "btrfs-list.h"
-#include "btrfsck.h"
+#include "check/btrfsck.h"
 #include "extent-cache.h"
 #include "send.h"
 #include "send-stream.h"
