@@ -31,8 +31,8 @@
 #include <ctype.h>
 #include <asm/types.h>
 #include <uuid/uuid.h>
-#include "utils.h"
-#include "commands.h"
+#include "common/utils.h"
+#include "cmds/commands.h"
 #include "send-utils.h"
 #include "send-stream.h"
 #include "send-dump.h"
