@@ -12,15 +12,18 @@ prepare_test_dev
 
 test_mkfs_mount_checksum()
 {
+	local csum
+
+	csum="$1"
 	run_check_stdout $SUDO_HELPER "$TOP/mkfs.btrfs" -f --csum "$csum" "$TEST_DEV" | grep -q "Checksum:.*$csum"
 	run_check $SUDO_HELPER "$TOP/btrfs" inspect-internal dump-super "$TEST_DEV"
 	run_check $SUDO_HELPER "$TOP/btrfs" check "$TEST_DEV"
 
-	run_check $SUDO_HELPER mount "$dev1" "$TEST_MNT"
+	run_check_mount_test_dev
 	run_check "$TOP/btrfs" filesystem df "$TEST_MNT"
 	run_check $SUDO_HELPER "$TOP/btrfs" filesystem usage "$TEST_MNT"
 	run_check $SUDO_HELPER "$TOP/btrfs" device usage "$TEST_MNT"
-	run_check $SUDO_HELPER umount "$TEST_MNT"
+	run_check_umount_test_dev
 }
 
 if ! [ -f "/sys/fs/btrfs/features/supported_checksums" ]; then
